@@ -11,4 +11,6 @@
 # on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
-from .AddEntriesByUserId import AddEntriesByUserId
\ No newline at end of file
+from .AddEntriesByUserId import AddEntriesByUserId
+from .DeleteEntriesByUserId import DeleteEntriesByUserId
+from .VerifyEntryByUserId import VerifyEntryByUserId
\ No newline at end of file
