@@ -23,6 +23,7 @@ from ...core.model import LogSetting
 from ..ref.NamespaceRef import NamespaceRef
 from .CurrentMasterData import CurrentMasterData
 from .RateModel import RateModel
+from .UnleashRateModel import UnleashRateModel
 
 from .options.NamespaceOptions import NamespaceOptions
 
@@ -30,9 +31,9 @@ from .options.NamespaceOptions import NamespaceOptions
 class Namespace(CdkResource):
     stack: Stack
     name: str
-    transaction_setting: TransactionSetting
     description: Optional[str] = None
     enable_direct_enhance: Optional[bool] = None
+    transaction_setting: Optional[TransactionSetting] = None
     enhance_script: Optional[ScriptSetting] = None
     log_setting: Optional[LogSetting] = None
 
@@ -40,7 +41,6 @@ class Namespace(CdkResource):
         self,
         stack: Stack,
         name: str,
-        transaction_setting: TransactionSetting,
         options: Optional[NamespaceOptions] = NamespaceOptions(),
     ):
         super().__init__(
@@ -49,9 +49,9 @@ class Namespace(CdkResource):
 
         self.stack = stack
         self.name = name
-        self.transaction_setting = transaction_setting
         self.description = options.description if options.description else None
         self.enable_direct_enhance = options.enable_direct_enhance if options.enable_direct_enhance else None
+        self.transaction_setting = options.transaction_setting if options.transaction_setting else None
         self.enhance_script = options.enhance_script if options.enhance_script else None
         self.log_setting = options.log_setting if options.log_setting else None
         stack.add_resource(
@@ -103,19 +103,21 @@ class Namespace(CdkResource):
         self,
     ) -> GetAttr:
         return GetAttr(
-            None,
-            None,
+            self,
             "Item.NamespaceId",
+            None,
         )
 
     def master_data(
         self,
         rate_models: List[RateModel],
+        unleash_rate_models: List[UnleashRateModel],
     ) -> Namespace:
         CurrentMasterData(
             self.stack,
             self.name,
             rate_models,
+            unleash_rate_models,
         ).add_depends_on(
             self,
         )
