@@ -17,4 +17,9 @@ from .ExperienceModel import ExperienceModel
 from .options.ExperienceModelOptions import ExperienceModelOptions
 from .Threshold import Threshold
 from .options.ThresholdOptions import ThresholdOptions
+from .AcquireActionRate import AcquireActionRate
+from .options.AcquireActionRateOptions import AcquireActionRateOptions
+from .enum.AcquireActionRateMode import AcquireActionRateMode
+from .options.AcquireActionRateModeIsDoubleOptions import AcquireActionRateModeIsDoubleOptions
+from .options.AcquireActionRateModeIsBigOptions import AcquireActionRateModeIsBigOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
