@@ -22,6 +22,7 @@ from ..stamp_sheet.SetMoldCapacityByUserId import SetMoldCapacityByUserId
 from ..stamp_sheet.AcquireActionsToFormProperties import AcquireActionsToFormProperties
 from ...core.model import AcquireAction
 from ...core.model import Config
+from ..stamp_sheet.SetFormByUserId import SetFormByUserId
 from ..stamp_sheet.AcquireActionsToPropertyFormProperties import AcquireActionsToPropertyFormProperties
 from ..stamp_sheet.SubMoldCapacityByUserId import SubMoldCapacityByUserId
 
@@ -96,6 +97,21 @@ class NamespaceRef:
             user_id,
         )
 
+    def set_form(
+        self,
+        mold_model_name: str,
+        index: int,
+        slots: List[Slot],
+        user_id: Optional[str] = "#{userId}",
+    ) -> SetFormByUserId:
+        return SetFormByUserId(
+            self.namespace_name,
+            mold_model_name,
+            index,
+            slots,
+            user_id,
+        )
+
     def acquire_actions_to_property_form_properties(
         self,
         property_form_model_name: str,
