@@ -146,6 +146,7 @@ class InventoryModelRef:
         self,
         verify_type: str,
         current_inventory_max_capacity: int,
+        multiply_value_specifying_quantity: Optional[bool] = None,
         user_id: Optional[str] = "#{userId}",
     ) -> VerifyInventoryCurrentMaxCapacityByUserId:
         return VerifyInventoryCurrentMaxCapacityByUserId(
@@ -153,6 +154,7 @@ class InventoryModelRef:
             self.inventory_name,
             verify_type,
             current_inventory_max_capacity,
+            multiply_value_specifying_quantity,
             user_id,
         )
 
@@ -178,6 +180,7 @@ class InventoryModelRef:
         verify_type: str,
         count: int,
         item_set_name: Optional[str] = None,
+        multiply_value_specifying_quantity: Optional[bool] = None,
         user_id: Optional[str] = "#{userId}",
     ) -> VerifyItemSetByUserId:
         return VerifyItemSetByUserId(
@@ -187,6 +190,7 @@ class InventoryModelRef:
             verify_type,
             count,
             item_set_name,
+            multiply_value_specifying_quantity,
             user_id,
         )
 
