@@ -28,7 +28,6 @@ class Namespace(CdkResource):
     stack: Stack
     name: str
     description: Optional[str] = None
-    enable_auto_run: Optional[bool] = None
     push_notification: Optional[NotificationSetting] = None
     run_notification: Optional[NotificationSetting] = None
     log_setting: Optional[LogSetting] = None
@@ -46,7 +45,6 @@ class Namespace(CdkResource):
         self.stack = stack
         self.name = name
         self.description = options.description if options.description else None
-        self.enable_auto_run = options.enable_auto_run if options.enable_auto_run else None
         self.push_notification = options.push_notification if options.push_notification else None
         self.run_notification = options.run_notification if options.run_notification else None
         self.log_setting = options.log_setting if options.log_setting else None
@@ -74,8 +72,7 @@ class Namespace(CdkResource):
             properties["Name"] = self.name
         if self.description is not None:
             properties["Description"] = self.description
-        if self.enable_auto_run is not None:
-            properties["EnableAutoRun"] = self.enable_auto_run
+        properties["EnableAutoRun"] = True
         if self.push_notification is not None:
             properties["PushNotification"] = self.push_notification.properties(
             )
@@ -99,7 +96,7 @@ class Namespace(CdkResource):
         self,
     ) -> GetAttr:
         return GetAttr(
-            None,
-            None,
+            self,
             "Item.NamespaceId",
+            None,
         )
