@@ -16,6 +16,8 @@ from typing import *
 
 from ...core.func import GetAttr, Join
 from .RatingModelRef import RatingModelRef
+from .SeasonModelRef import SeasonModelRef
+from ..stamp_sheet.VerifyIncludeParticipantByUserId import VerifyIncludeParticipantByUserId
 
 
 class NamespaceRef:
@@ -36,6 +38,34 @@ class NamespaceRef:
             rating_name,
         )
 
+    def season_model(
+        self,
+        season_name: str,
+    ) -> SeasonModelRef:
+        return SeasonModelRef(
+            self.namespace_name,
+            season_name,
+        )
+
+    def verify_include_participant(
+        self,
+        season_name: str,
+        season: int,
+        tier: int,
+        verify_type: str,
+        season_gathering_name: Optional[str] = None,
+        user_id: Optional[str] = "#{userId}",
+    ) -> VerifyIncludeParticipantByUserId:
+        return VerifyIncludeParticipantByUserId(
+            self.namespace_name,
+            season_name,
+            season,
+            tier,
+            verify_type,
+            season_gathering_name,
+            user_id,
+        )
+
     def grn(
         self,
     ) -> str:
