@@ -33,8 +33,14 @@ from .options.MissionGroupModelResetTypeIsWeeklyOptions import MissionGroupModel
 from .options.MissionGroupModelResetTypeIsMonthlyOptions import MissionGroupModelResetTypeIsMonthlyOptions
 from .MissionTaskModel import MissionTaskModel
 from .options.MissionTaskModelOptions import MissionTaskModelOptions
+from .enum.MissionTaskModelVerifyCompleteType import MissionTaskModelVerifyCompleteType
 from .enum.MissionTaskModelTargetResetType import MissionTaskModelTargetResetType
+from .options.MissionTaskModelVerifyCompleteTypeIsCounterOptions import MissionTaskModelVerifyCompleteTypeIsCounterOptions
+from .options.MissionTaskModelVerifyCompleteTypeIsConsumeActionsOptions import MissionTaskModelVerifyCompleteTypeIsConsumeActionsOptions
 from .ScopedValue import ScopedValue
 from .options.ScopedValueOptions import ScopedValueOptions
 from .enum.ScopedValueResetType import ScopedValueResetType
+from .TargetCounterModel import TargetCounterModel
+from .options.TargetCounterModelOptions import TargetCounterModelOptions
+from .enum.TargetCounterModelResetType import TargetCounterModelResetType
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
