@@ -14,4 +14,10 @@
 from .Namespace import Namespace
 from .options.NamespaceOptions import NamespaceOptions
 from .Script import Script
-from .options.ScriptOptions import ScriptOptions
\ No newline at end of file
+from .options.ScriptOptions import ScriptOptions
+from .RandomStatus import RandomStatus
+from .options.RandomStatusOptions import RandomStatusOptions
+from .RandomUsed import RandomUsed
+from .options.RandomUsedOptions import RandomUsedOptions
+from .Transaction import Transaction
+from .options.TransactionOptions import TransactionOptions
\ No newline at end of file
