@@ -46,7 +46,7 @@ class CampaignModelRef:
                 ),
                 "serialKey",
                 self.namespace_name,
-                "master",
+                "model",
                 "campaign",
                 self.campaign_model_name,
             ],
